#!/bin/sh

SYNODNSTOOL="/var/packages/DNSServer/target/app/synodnstool"

is_vpn_iface()
{
	if ! echo "${IFNAME}" | /bin/grep -q 'ppp[2-3]\{1\}[0-9]\{2\}'; then
		return 1
	fi

	if [[ "ppp200" == "${IFNAME}" ]] || [[ "ppp300" == "${IFNAME}" ]]; then
		return 1
	fi

	return 0
}

is_skip()
{
	# do nothing when booting-up
	if /usr/syno/bin/synobootseq --is-booting-up > /dev/null 2>&1 ; then
		return 0
	fi
	# do nothing when shutdown
	if /usr/syno/bin/synobootseq --is-shutdown > /dev/null 2>&1 ; then
		return 0
	fi
	# ignores the events comming from the interfaces for PPTP/L2TP server-side,
	# whose names are in the range of ppp201-299 and ppp301-399, because no
	# services interested them.
	if is_vpn_iface; then
		return 0
	fi
	# ignore quickconnect interface
	if [[ "tun1000" == "${IFNAME}" ]]; then
		return 0
	fi
	if ! pidof named > /dev/null 2>&1 ; then
		return 0
	fi
	return 1
}

dns_setup_named_ipv6()
{
	"${SYNODNSTOOL}" --setup-named-ipv6
}

dns_if_link_ipv6_change_action()
{
	dns_setup_named_ipv6
}

case $1 in
	--sdk-mod-ver)
		#Print SDK support version
		echo "1.0"
		;;
	--name)
		#Print package name
		echo "synodns"
		;;
	--pkg-ver)
		#Print package version
		echo "1.0"
		;;
	--vendor)
		#Print package vendor
		echo "Synology"
		;;
	--post)
		if is_skip; then
			exit 0
		fi
		dns_if_link_ipv6_change_action &
		;;
	*)
		echo "Usage: $0 --sdk-mod-ver|--name|--pkg-ver|--vendor|--pre|--post"
		;;
esac

# vim: set ts=4 sts=0 sw=4 noet:
